@@ -25,6 +25,7 @@
 #include <QPointer>
 #include <QStack>
 #include <QMimeType>
+#include <QTimer>
 
 #include <KJob>
 
@@ -40,9 +41,8 @@
 
 #include <ktexteditor_export.h>
 #include "katetextline.h"
-#include "katetextcursor.h"
-#include "katetextrange.h"
 
+class KateTemplateHandler;
 namespace KTextEditor
 {
 class Plugin;
@@ -348,11 +348,22 @@ public:
 
     void setUndoMergeAllEdits(bool merge);
 
+    enum EditingPositionKind { Previous, Next };
+
+   /**
+    *Returns the next or previous position cursor in this document from the stack depending on the argument passed.
+    *@return cursor invalid if m_editingStack empty
+    */
+    KTextEditor::Cursor lastEditingPosition(EditingPositionKind nextOrPrevious, KTextEditor::Cursor);
+
 private:
     int editSessionNumber;
     QStack<int> editStateStack;
     bool editIsRunning;
     bool m_undoMergeAllEdits;
+    QStack<QSharedPointer<KTextEditor::MovingCursor>> m_editingStack;
+    int m_editingStackPosition = -1;
+    static const int s_editingStackSizeLimit = 32;
 
     //
     // KTextEditor::UndoInterface stuff
@@ -361,6 +372,18 @@ public Q_SLOTS:
     void undo();
     void redo();
 
+    /**
+     * Removes all the elements in m_editingStack of the respective document.
+     */
+    void clearEditingPosStack();
+
+    /**
+     * Saves the editing positions into the stack.
+     * If the consecutive editings happens in the same line, then remove
+     * the previous and add the new one with updated column no.
+     */
+    void saveEditingPositions(KTextEditor::Document *, const KTextEditor::Range &range);
+
 public:
     uint undoCount() const;
     uint redoCount() const;
@@ -983,6 +1006,7 @@ private Q_SLOTS:
     void slotModOnHdDirty(const QString &path);
     void slotModOnHdCreated(const QString &path);
     void slotModOnHdDeleted(const QString &path);
+    void slotDelayedHandleModOnHd();
 
 private:
     /**
@@ -1359,6 +1383,21 @@ public:
 
 public Q_SLOTS:
     void openWithLineLengthLimitOverride();
+    
+private:
+    /**
+     * timer for delayed handling of mod on hd
+     */
+    QTimer m_modOnHdTimer;
+
+private:
+    /**
+     * currently active template handler; there can be only one
+     */
+    QPointer<KateTemplateHandler> m_activeTemplateHandler;
+
+public:
+    void setActiveTemplateHandler(KateTemplateHandler* handler);
 };
 
 #endif
