@@ -717,6 +717,8 @@ public:
     // the line number color is used for the line numbers on the left bar
     const QColor &lineNumberColor() const;
     void setLineNumberColor(const QColor &col);
+    const QColor &currentLineNumberColor() const;
+    void setCurrentLineNumberColor(const QColor &col);
 
     // the color of the separator between line numbers and icon bar
     const QColor &separatorColor() const;
@@ -770,6 +772,7 @@ private:
     QColor m_iconBarColor;
     QColor m_foldingColor;
     QColor m_lineNumberColor;
+    QColor m_currentLineNumberColor;
     QColor m_separatorColor;
     QColor m_spellingMistakeLineColor;
     QVector<QColor> m_lineMarkerColor;
@@ -804,6 +807,7 @@ private:
     bool m_iconBarColorSet : 1;
     bool m_foldingColorSet : 1;
     bool m_lineNumberColorSet : 1;
+    bool m_currentLineNumberColorSet : 1;
     bool m_separatorColorSet : 1;
     bool m_spellingMistakeLineColorSet : 1;
     bool m_templateColorsSet : 1;
